qcacmn: Add lmac support for vdev delete all peer

Add lmac support for vdev delete all
peer request which will replace individual peer
delete for peers under a vdev during vdev down.

Change-Id: I98b5228c17b08eedd50b82372efe1b249cef2699
CRs-Fixed: 2477650
diff --git a/umac/global_umac_dispatcher/lmac_if/inc/wlan_lmac_if_def.h b/umac/global_umac_dispatcher/lmac_if/inc/wlan_lmac_if_def.h
index 03e5fb1..776854b 100644
--- a/umac/global_umac_dispatcher/lmac_if/inc/wlan_lmac_if_def.h
+++ b/umac/global_umac_dispatcher/lmac_if/inc/wlan_lmac_if_def.h
@@ -212,7 +212,7 @@
  * @beacon_tmpl_send: function to send beacon template
  * @vdev_bcn_miss_offload_send: function to send beacon miss offload
  * @vdev_sta_ps_param_send: function to sent STA power save config
- * @target_is_pre_lithium: function to get target type status
+ * @peer_delete_all_send: function to send vdev delete all peer request
  */
 struct wlan_lmac_if_mlme_tx_ops {
 	void (*scan_sta_power_events)(struct wlan_objmgr_pdev *pdev,
@@ -277,6 +277,9 @@
 	QDF_STATUS (*vdev_bcn_miss_offload_send)(struct wlan_objmgr_vdev *vdev);
 	QDF_STATUS (*vdev_sta_ps_param_send)(struct wlan_objmgr_vdev *vdev,
 					     struct sta_ps_params *param);
+	QDF_STATUS (*peer_delete_all_send)(
+					struct wlan_objmgr_vdev *vdev,
+					struct peer_delete_all_params *param);
 #endif
 };
 
@@ -1389,13 +1392,16 @@
  * @wlan_mlme_get_traffic_indication_timestamp: function to get tid timestamp
  * @wlan_mlme_get_acs_in_progress: function to get ACS progress
  * @wlan_mlme_end_scan: function to end scan
  * @mlme_get_rsp_timer: function to get vdev mgr response timer
  * @mlme_response_timeout_cb: function to trigger on response time expiry
  * @mlme_start_response: function to handle vdev start response
  * @mlme_stop_response: function to handle vdev stop response
  * @mlme_offload_bcn_tx_status_event_handle: function to get offload beacon tx
  * status
  * @mlme_tbttoffset_update_handle: function to handle tbttoffset event
  */
 struct wlan_lmac_if_mlme_rx_ops {
 
@@ -1473,6 +1479,9 @@
 	QDF_STATUS (*vdev_mgr_tbttoffset_update_handle)(
 						uint32_t num_vdevs,
 						bool is_ext);
+	QDF_STATUS (*vdev_mgr_peer_delete_all_response)(
+					struct wlan_objmgr_psoc *psoc,
+					struct peer_delete_all_response *rsp);
 #ifdef FEATURE_VDEV_RSP_WAKELOCK
 	struct vdev_mlme_wakelock *(*vdev_mgr_get_wakelock_info)(
 					struct wlan_objmgr_vdev *vdev);
@@ -1389,13 +1392,16 @@
  * @wlan_mlme_get_acs_in_progress: function to get ACS progress
  * @wlan_mlme_end_scan: function to end scan
- * @mlme_get_rsp_timer: function to get vdev mgr response timer
- * @mlme_response_timeout_cb: function to trigger on response time expiry
- * @mlme_start_response: function to handle vdev start response
- * @mlme_stop_response: function to handle vdev stop response
- * @mlme_offload_bcn_tx_status_event_handle: function to get offload beacon tx
- * status
- * @mlme_tbttoffset_update_handle: function to handle tbttoffset event
+ * @vdev_mgr_get_response_timer_info: function to get response timer info
+ * @vdev_mgr_start_response: function to handle start response
+ * @vdev_mgr_stop_response: function to handle stop response
+ * @vdev_mgr_delete_response: function to handle delete response
+ * @vdev_mgr_offload_bcn_tx_status_event_handle: function to handle offload
+ * beacon tx
+ * @vdev_mgr_tbttoffset_update_handle: function to handle tbtt offset event
+ * @vdev_mgr_peer_delete_all_response: function to handle vdev delete all peer
+ * event
+ * @vdev_mgr_get_wakelock_info: function to get wakelock info
  */
 struct wlan_lmac_if_mlme_rx_ops {